@@ -251,7 +251,7 @@ class ImageRecognition(object):
                 for j in range(perclass_sample):
                     if idx[i] >= len(file_list_by_class[i]):
                         random.shuffle(file_list_by_class[i])
-                        print ("==>>> INFO: your " + message + " in class " + str(i) + " dataset is reshuffled again", idx[i])
+                        #print ("==>>> INFO: your " + message + " in class " + str(i) + " dataset is reshuffled again", idx[i])
                         idx[i] = 0
                     try:
                         tmp_x = cv2.imread(dataset_path + i + "/" + file_list_by_class[i][idx[i]])
